@@ -7,19 +7,11 @@ import warnings
 import pandas as pd
 
 warnings.filterwarnings("ignore")
-series_type = pandas.core.series.Series
 dataframe_type = pandas.core.frame.DataFrame
+series_type = pandas.core.series.Series
 dict_type = dict
 
 
-def check_series_type(func):
-    def wrapper(*args, **kwargs):
-        assert type(args[1]) == series_type
-        return func(*args, **kwargs)
-
-    return wrapper
-
-
 def check_dict_type(func):
     def wrapper(*args, **kwargs):
         assert type(args[1]) == dict_type
@@ -100,8 +92,8 @@ class SuperPipeObject(object):
     name:模块名称，如果为空默认为self.__class__
     input_col_names:输入数据的columns
     output_col_names:输出数据的columns
-    transform_check_max_number_error:在auto_check_transform时允许的最大数值误差
-    skip_check_transform_type:在auto_check_transform时是否跳过类型检测(针对一些特殊数据类型，比如稀疏矩阵)
+    transform_check_max_number_error:在check_transform_function时允许的最大数值误差
+    skip_check_transform_type:在check_transform_function时是否跳过类型检测(针对一些特殊数据类型，比如稀疏矩阵)
     leak_check_transform_type:弱化类型检测，比如将int32和int64都视为int类型
     leak_check_transform_value:弱化检测值，将None视为相等
     copy_transform_data:transform阶段是否要copy一次数据
@@ -208,58 +200,63 @@ class SuperPipeObject(object):
         # 输出指定columns
         return self.extract_dict(s, self.output_col_names)
 
-    def auto_check_transform(self, s_):
+    def _run_batch_single_transform(self, s_):
         """
-        自动测试批量接口和单条数据接口
+        分别获取batch_transform和single_transform预测
         """
-        # 预测数据
         s = copy.copy(s_)
         batch_transform = self.transform(s)  # 注意:transform可能会修改s自身数据
         single_transform = []
         single_operate_times = []
         s = copy.copy(s_)
-        if type(s) == dataframe_type:
-            for record in s.to_dict("record"):
-                start_time = datetime.datetime.now()
-                single_transform.append(self.transform_single(record))
-                end_time = datetime.datetime.now()
-                single_operate_times.append((end_time - start_time).microseconds / 1000)
-            single_transform = pandas.DataFrame(single_transform)
-        else:  # series_type
-            for value in s.values:
-                start_time = datetime.datetime.now()
-                single_transform.append(self.transform_single({self.input_col_names[0]: value}))
-                end_time = datetime.datetime.now()
-                single_operate_times.append((end_time - start_time).microseconds / 1000)
-            single_transform = pandas.DataFrame(single_transform)
-        # 都转换为dataframe,方便统一检测
-        new_batch_transform = batch_transform
-        if type(batch_transform) == series_type:
-            new_batch_transform = pandas.DataFrame({self.output_col_names[0]: batch_transform.values})
-        # 检验
-        # 检验1:输出shape是否一致
-        if new_batch_transform.shape != single_transform.shape:
-            raise Exception(
-                "({})  module shape error , batch shape is {} , single  shape is {}".format(
-                    self.name, new_batch_transform.shape, single_transform.shape))
+        for record in s.to_dict("record"):
+            start_time = datetime.datetime.now()
+            single_transform.append(self.transform_single(record))
+            end_time = datetime.datetime.now()
+            single_operate_times.append((end_time - start_time).microseconds / 1000)
+        single_transform = pandas.DataFrame(single_transform)
+        return batch_transform, single_transform, single_operate_times
 
-        for col in new_batch_transform.columns:
-            # 检验2:输出名称是否一致
+    def _check_shape(self, batch_transform, single_transform):
+        """
+        检测shape是否一致
+        """
+        if batch_transform.shape != single_transform.shape:
+            raise Exception(
+                "({})  module output shape error , batch shape is {} , single  shape is {}".format(
+                    self.name, batch_transform.shape, single_transform.shape))
+
+    def _check_columns(self, batch_transform, single_transform):
+        """
+        检测输出的column是否一致
+        """
+        for col in batch_transform.columns:
             if col not in single_transform.columns:
                 raise Exception(
-                    "({})  module column error,the batch output column {} not in single output".format(
+                    "({})  module output column error,the batch output column {} not in single output".format(
                         self.name, col))
-            # 检验3:数据类型是否一致
-            if not self.skip_check_transform_type and not self._leak_check_type_is_same(new_batch_transform[col].dtype,
+
+    def _check_data_type(self, batch_transform, single_transform):
+        """
+        检测数据类型是否一致
+        """
+        for col in batch_transform.columns:
+            if not self.skip_check_transform_type and not self._leak_check_type_is_same(batch_transform[col].dtype,
                                                                                         single_transform[col].dtype):
                 raise Exception(
-                    "({})  module type error,the column {} in batch is {},while in single is {}".format(
-                        self.name, col, new_batch_transform[col].dtype, single_transform[col].dtype))
-            # 检验4:数值是否一致
-            col_type = str(new_batch_transform[col].dtype)
-            batch_col_values = new_batch_transform[col].values
+                    "({})  module output type error,the column {} in batch is {},while in single is {}".format(
+                        self.name, col, batch_transform[col].dtype, single_transform[col].dtype))
+
+    def _check_data_same(self, batch_transform, single_transform):
+        """
+        检测数值是否一致
+        """
+        for col in batch_transform.columns:
+            col_type = str(batch_transform[col].dtype)
+            batch_col_values = batch_transform[col].values
             single_col_values = single_transform[col].values
             if not self.skip_check_transform_value and ("int" in col_type or "float" in col_type):
+                # 数值数据检测
                 try:
                     batch_col_values = batch_col_values.to_dense()  # 转换为dense
                 except:
@@ -274,20 +271,21 @@ class SuperPipeObject(object):
                     # 再做一次弱检测
                     if self._leak_check_value_is_same(error_info["batch_transform"], error_info["single_transform"]):
                         format_info = """
-----------------------------------------------------
-({})  module value is unsafe,in col \033[1;43m[{}]\033[0m,current transform_check_max_number_error is {},
-the top {} error info is \n {}
-----------------------------------------------------"
-                        """
+        ----------------------------------------------------
+        ({})  module output value is unsafe,in col \033[1;43m[{}]\033[0m,current transform_check_max_number_error is {},
+        the top {} error info is \n {}
+        ----------------------------------------------------"
+                                """
                         print(format_info.format(self.name, col, self.transform_check_max_number_error,
                                                  min(3, len(error_info)), error_info))
                     else:
                         raise Exception(
-                            "({})  module value error,in col [{}],current transform_check_max_number_error is {} ,"
+                            "({}) module output value error,in col [{}],current transform_check_max_number_error is {},"
                             "the top {} error info is \n {}".format(
                                 self.name, col, self.transform_check_max_number_error, min(3, len(error_info)),
                                 error_info))
             elif not self.skip_check_transform_value:
+                # 离散数据检测
                 error_index = np.argwhere(batch_col_values != single_col_values)
                 if len(error_index) > 0:
                     error_info = pd.DataFrame(
@@ -297,16 +295,32 @@ the top {} error info is \n {}
                     # 再做一次弱检测
                     if self._leak_check_value_is_same(error_info["batch_transform"], error_info["single_transform"]):
                         format_info = """
-----------------------------------------------------
-({})  module value is unsafe,in col \033[1;43m[{}]\033[0m
-the top {} error info is \n {}
-----------------------------------------------------"
-                        """
+        ----------------------------------------------------
+        ({})  module output value is unsafe,in col \033[1;43m[{}]\033[0m
+        the top {} error info is \n {}
+        ----------------------------------------------------"
+                                """
                         print(format_info.format(self.name, col, min(3, len(error_info)), error_info))
                     else:
                         raise Exception(
-                            "({})  module value error,in col [{}] ,the top {} error info is \n {}".format(
+                            "({})  module output value error,in col [{}] ,the top {} error info is \n {}".format(
                                 self.name, col, min(3, len(error_info)), error_info))
+
+    def check_transform_function(self, s_):
+        """
+        自动测试批量接口和单条数据接口
+        """
+        # 运行batch和single transform
+        batch_transform, single_transform, single_operate_times = self._run_batch_single_transform(s_)
+        # 检验1:输出shape是否一致
+        self._check_shape(batch_transform, single_transform)
+        # 检验2:输出名称是否一致
+        self._check_columns(batch_transform, single_transform)
+        # 检验3:数据类型是否一致
+        self._check_data_type(batch_transform, single_transform)
+        # 检验4:数值是否一致
+        self._check_data_same(batch_transform, single_transform)
+        # 打印运行成功信息
         print("({})  module transform check [success], single transform speed:[{}]ms/it".format(self.name, np.round(
             np.mean(single_operate_times), 2)))
         return batch_transform
